Data Exchange Layer (DXL) Overview
========

The "Security Connected" Vision
-------------------------------

An adaptive (security) system of interconnected services that communicate and share information to make real-time,
accurate security decisions by individual security products and/or as a collective. Network, endpoint, mobile
and other security solutions are no longer to operate as separate "silos", but as one synchronized, real-time,
adaptive, security system.

What is the Data Exchange Layer?
--------------------------------

The Data Exchange Layer (DXL) is the foundation for making the Security Connected vision a reality.
It is an ePO-managed framework for enabling real-time security context sharing between products,
to enable adaptive security, and for treating appropriately designed products as services.
In short, it allows for scalable communication between anything on the DXL network "fabric" through an
easy-to-use, easy-to-manage product.

